# vasp.runners module

```{eval-rst}
.. automodule:: vasp.runners
   :members:
   :undoc-members:
   :show-inheritance:
```

## Base Classes

```{eval-rst}
.. autoclass:: vasp.runners.Runner
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: vasp.runners.JobStatus
   :members:
   :undoc-members:
   :show-inheritance:
```

## Runners

```{eval-rst}
.. autoclass:: vasp.runners.LocalRunner
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: vasp.runners.MockRunner
   :members:
   :undoc-members:
   :show-inheritance:
```
